import os
import sys
import numpy

import numpy.core.multiarray
import numpy.core.multiarray_tests
import numpy.core.numeric
import numpy.core.operand_flag_tests
import numpy.core.struct_ufunc_test
import numpy.core.test_rational
import numpy.core.umath
import numpy.core.umath_tests
import numpy.fft.fftpack_lite
import numpy.linalg.lapack_lite
import numpy.random.mtrand

if sys.version_info[:2] >= (3, 7):
    print("WARNING: Skipping tests as numpy 1.11 tests incompatible with Python 3.7")
    sys.exit(0)

sys.exit(not numpy.test().wasSuccessful())
